@@ -137,6 +137,7 @@ from web3.types import (  # noqa: F401
     ABIEvent,
     ABIFunction,
     BlockIdentifier,
+    CallOverrideParams,
     EventData,
     FunctionIdentifier,
     LogReceipt,
@@ -688,7 +689,9 @@ class ContractConstructor:
     ) -> None:
         keys_found = set(transaction.keys()) & set(forbidden_keys)
         if keys_found:
-            raise ValueError("Cannot set {} in transaction".format(', '.join(keys_found)))
+            raise ValueError(
+                "Cannot set '{}' field(s) in transaction".format(', '.join(keys_found))
+            )
 
 
 class ConciseMethod:
@@ -897,7 +900,9 @@ class ContractFunction:
         self.arguments = merge_args_and_kwargs(self.abi, self.args, self.kwargs)
 
     def call(
-        self, transaction: Optional[TxParams] = None, block_identifier: BlockIdentifier = 'latest'
+        self, transaction: Optional[TxParams] = None,
+        block_identifier: BlockIdentifier = 'latest',
+        state_override: Optional[CallOverrideParams] = None,
     ) -> Any:
         """
         Execute a contract function call using the `eth_call` interface.
@@ -929,7 +934,7 @@ class ContractFunction:
             call_transaction = cast(TxParams, dict(**transaction))
 
         if 'data' in call_transaction:
-            raise ValueError("Cannot set data in call transaction")
+            raise ValueError("Cannot set 'data' field in call transaction")
 
         if self.address:
             call_transaction.setdefault('to', self.address)
@@ -960,6 +965,7 @@ class ContractFunction:
             block_id,
             self.contract_abi,
             self.abi,
+            state_override,
             *self.args,
             **self.kwargs
         )
@@ -971,7 +977,7 @@ class ContractFunction:
             transact_transaction = cast(TxParams, dict(**transaction))
 
         if 'data' in transact_transaction:
-            raise ValueError("Cannot set data in transact transaction")
+            raise ValueError("Cannot set 'data' field in transact transaction")
 
         if self.address is not None:
             transact_transaction.setdefault('to', self.address)
@@ -1011,7 +1017,7 @@ class ContractFunction:
             estimate_gas_transaction = cast(TxParams, dict(**transaction))
 
         if 'data' in estimate_gas_transaction:
-            raise ValueError("Cannot set data in estimateGas transaction")
+            raise ValueError("Cannot set 'data' field in estimateGas transaction")
         if 'to' in estimate_gas_transaction:
             raise ValueError("Cannot set to in estimateGas transaction")
 
@@ -1054,7 +1060,7 @@ class ContractFunction:
             built_transaction = cast(TxParams, dict(**transaction))
 
         if 'data' in built_transaction:
-            raise ValueError("Cannot set data in build transaction")
+            raise ValueError("Cannot set 'data' field in build transaction")
 
         if not self.address and 'to' not in built_transaction:
             raise ValueError(
@@ -1062,7 +1068,7 @@ class ContractFunction:
                 "you must provide a `to` address with the transaction"
             )
         if self.address and 'to' in built_transaction:
-            raise ValueError("Cannot set to in contract call build transaction")
+            raise ValueError("Cannot set 'to' field in contract call build transaction")
 
         if self.address:
             built_transaction.setdefault('to', self.address)
@@ -1160,9 +1166,9 @@ class ContractEvent:
                     raise e
                 else:
                     warnings.warn(
-                        f"The log with transaction hash: {log['transactionHash']} and "
+                        f"The log with transaction hash: {log['transactionHash']!r} and "
                         f"logIndex: {log['logIndex']} encountered the following error "
-                        f'during processing: {type(e).__name__}({e}). It has been discarded.'
+                        f"during processing: {type(e).__name__}({e}). It has been discarded."
                     )
                     continue
             yield rich_log
@@ -1476,6 +1482,7 @@ def call_contract_function(
         block_id: Optional[BlockIdentifier] = None,
         contract_abi: Optional[ABI] = None,
         fn_abi: Optional[ABIFunction] = None,
+        state_override: Optional[CallOverrideParams] = None,
         *args: Any,
         **kwargs: Any) -> Any:
     """
@@ -1493,10 +1500,11 @@ def call_contract_function(
         fn_kwargs=kwargs,
     )
 
-    if block_id is None:
-        return_data = web3.eth.call(call_transaction)
-    else:
-        return_data = web3.eth.call(call_transaction, block_identifier=block_id)
+    return_data = web3.eth.call(
+        call_transaction,
+        block_identifier=block_id,
+        state_override=state_override,
+    )
 
     if fn_abi is None:
         fn_abi = find_matching_fn_abi(contract_abi, web3.codec, function_identifier, args, kwargs)
@@ -1518,12 +1526,8 @@ def call_contract_function(
             )
         else:
             msg = (
-                "Could not decode contract function call {} return data {} for "
-                "output_types {}".format(
-                    function_identifier,
-                    return_data,
-                    output_types
-                )
+                f"Could not decode contract function call to {function_identifier} with "
+                f"return data: {str(return_data)}, output_types: {output_types}"
             )
         raise BadFunctionCallOutput(msg) from e
 
